udata=read.csv('/home/simon/Projects/AgeMethylation/HumpbackAgeMethylationPaper/Data/CalibrationSamplesCpGMeth.csv')
tdata <- udata[order(udata$Age),]
rownames(tdata) <- NULL
Age=tdata$Age
id=tdata$i.d.
C1=tdata$CDK2NA_A
C2=tdata$TET_C
C3=tdata$GRIA1
C4=tdata$TET2
C5=tdata$CDK2NA_C

par(mfrow=c(1,2))

#Multiple regression of all points
modelM=lm(formula=Age~C3+C2+C1)
influence.measures(modelM)
predictions <- predict(modelM)
plot(predictions~Age,col='blue',cex=2,cex.axis=0.7,cex.main=1.0,labels=TRUE,ylim=c(-10,35),yaxp=c(-10,35,9),xlim=c(-10,35),xaxp=c(-10,35,9),xlab='Known age',ylab='Estimated age',main='(A) HEAA multiple linear regression')
modelp=lm(formula=predictions~Age)
abline(v=(seq(0,35,5)), col="gray", lty="dotted")
abline(h=(seq(-10,35,5)), col="gray", lty="dotted")
abline(modelp,col='red')
summary(modelp)

coeff=summary(modelp)$coefficients
yInt=coeff[1,1]
yIntP=coeff[1,4]
yIntText=toString(signif(yInt,4))
yIntPtext=toString(signif(yIntP,4))
yIntText=paste('y intercept = ',yIntText,' p =',yIntPtext)
R2=summary(modelp)$adj.r.squared
overallR2=signif(R2,3)
overallR2=toString(overallR2)
overallR2=paste('R2 = ',overallR2)
sigR2=signif(summary(modelp)$coefficients[2,4],3)
sigR2=toString(sigR2)
sigR2=paste(' p = ',sigR2)
overallR2=paste(overallR2,sigR2)
#legend('topleft',cex=0.5,ncol=1,legend=c(overallR2,yIntText))

#Add 95% confidence lines for regression
a <- predict(modelp, interval="confidence",level=0.95) 
lines(Age,a[,2], lty=3,col='red')
lines(Age,a[,3], lty=3,col='red') 

#Perform LOOCV to get range of predictions around regression, corrected for y intercept
removeOne <- function(dat,x) {
  list=seq(1,dat)
  x=x-1
  v1=c(list[1:x])
  x=x+2
  v2=c(list[x:length(list)])
  data=c(v1,v2)
  return (data)}

scale1=yInt/max(Age)
scaling=1+(1-R2)+scale1
scaling2=1+(1-R2)

nSamples=length(Age)
predictions2 <- c(1:nSamples)
predictions3 <- c(1:nSamples)
for (z in 1:nSamples)
  {
  indices=removeOne(nSamples,z)
  modelM=lm(formula=Age[indices]~C1[indices]+C2[indices]+C3[indices])
  newdata=data.frame(C1=C1[z],C2=C2[z],C3=C3[z])
  p=predict(modelM,newdata)
  #if (p<0){p=0}
  predictions2[z]=p 
  }

#Make uncorrected graph
differences <- c(1:nSamples)
for (z in 1:nSamples)
{
  diff=Age[z]-predictions2[z]
  if (diff<0){diff=diff*-1}
  differences[z]=diff
}
differences
summary(differences)
s = sd(differences)
t_star = qt(0.975, nSamples-1)
t.test(differences, conf.level=0.95)

x_bar = mean(differences)
mean=toString(signif(x_bar,4))
n = length(differences)
s = sd(differences)
ci_upper = x_bar + t_star*s/sqrt(n)
s
for (z in 1:length(differences))
  {if (differences[z]<0){differences[z]=differences[z]*-1}
}
s = sd(differences)
t_star = qt(0.975, n-1)
LSD=signif(t_star*sqrt(2*s),4)
LSD=toString(LSD)

plot(predictions2~Age,cex=2,col='blue',cex.axis=0.7,cex.main=1.0,labels=TRUE,ylim=c(-10,35),yaxp=c(-10,35,9),xlim=c(-10,35),xaxp=c(-10,35,9),xlab='Known age',ylab='Estimated age',main='(B) LOOCV precision analysis')
abline(v=(seq(0,35,5)), col="gray", lty="dotted")
abline(h=(seq(-10,35,5)), col="gray", lty="dotted")
modelp=lm(formula=predictions2~Age)
abline(modelp,col='red')
summary(modelp)

pred=signif(ci_upper*2,4)
mean=paste('Mean diff =',mean)
standardDeviation=paste('SD =',toString(signif(s,4)))
ninetyfive=paste('95% c.i.=',toString(pred))
LSD=paste('Least Sig Diff =',LSD)
#legend('topleft',cex=0.5,ncol=1,legend=c(mean,standardDeviation,ninetyfive,LSD))
a <- predict(modelp) 
lines(Age,a+ci_upper, lty=3,col='red')
lines(Age,a-ci_upper, lty=3,col='red') 
#Age
#predictions2
